camelot.camelot.empty_project.application_admin

Package camelot :: Package camelot :: Package empty_project :: Module application_admin |
[hide private]
[frames] | no frames]

# Source Code for Module camelot.camelot.empty_project.application_admin

     1  from camelot.view.application_admin import ApplicationAdmin
     2  from camelot.view import art
     3

     4 -class MyApplicationAdmin(ApplicationAdmin):
     5

     6 -  def __init__(self):
     7      super(MyApplicationAdmin, self).__init__([('relations', ('Relations', art.icon24('apps/system-users'))),

     8                                                ('configuration',('Configuration', art.icon24('categories/preferences-system'))),]

     9                                                )
    10      from camelot.model.memento import Memento
    11      from camelot.model.authentication import Person, Organization
    12      from camelot.model.i18n import Translation
    13      self.register(Memento, Memento.Admin)
    14      self.register(Person, Person.Admin)
    15      self.register(Organization, Organization.Admin)
    16      self.register(Translation, Translation.Admin)
    17